pub struct GpuProverBuilder { /* private fields */ }Expand description
Builder for creating a configured cached GPU prover.
Implementations
Sourceimpl GpuProverBuilder
impl GpuProverBuilder
pub fn new(app_bin_path: impl AsRef<Path>) -> Self
pub fn with_level(self, level: ProverLevel) -> Self
pub fn with_security(self, security: SecurityLevel) -> Self
Sourcepub fn with_config(self, config: GpuProverConfig) -> Self
pub fn with_config(self, config: GpuProverConfig) -> Self
Applies low-level configuration for the GPU prover. See
GpuProverConfig; the default is optimal for the vast majority of
workloads, so this is only needed for specific constraints or unusual
workloads.
pub fn build(self) -> Result<GpuProver>