pub struct Program { /* private fields */ }Expand description
Loaded Airbender program distribution, including manifest and artifacts.
Implementations
Sourceimpl Program
impl Program
pub fn load(dist_dir: impl AsRef<Path>) -> Result<Self>
pub fn dist_dir(&self) -> &Path
pub fn manifest(&self) -> &Manifest
pub fn app_bin(&self) -> &Path
pub fn app_elf(&self) -> &Path
pub fn app_text(&self) -> &Path
Sourcepub fn transpiler_runner(&self) -> TranspilerRunnerBuilder
pub fn transpiler_runner(&self) -> TranspilerRunnerBuilder
Create a transpiler runner builder bound to this program.
Sourcepub fn gpu_prover(&self) -> GpuProverBuilder
pub fn gpu_prover(&self) -> GpuProverBuilder
Create a GPU prover builder bound to this program.
Sourcepub fn dev_prover(&self) -> DevProverBuilder
pub fn dev_prover(&self) -> DevProverBuilder
Create a development prover builder bound to this program.
Sourcepub fn cpu_prover(&self) -> CpuProverBuilder
pub fn cpu_prover(&self) -> CpuProverBuilder
Create a CPU prover builder bound to this program.
Sourcepub fn dev_verifier(&self) -> DevVerifierBuilder
pub fn dev_verifier(&self) -> DevVerifierBuilder
Create a development verifier builder bound to this program.
Sourcepub fn real_verifier(&self, level: ProverLevel) -> RealVerifierBuilder
pub fn real_verifier(&self, level: ProverLevel) -> RealVerifierBuilder
Create a real verifier builder bound to this program.