pub struct RealProof { /* private fields */ }Expand description
Real cryptographic proof emitted by CPU/GPU provers.
Implementations
Sourceimpl RealProof
impl RealProof
pub fn security(&self) -> SecurityLevel
pub fn level(&self) -> ProverLevel
Sourcepub fn into_inner(self) -> UnrolledProgramProof
pub fn into_inner(self) -> UnrolledProgramProof
Returns the wrapped unrolled proof.
Using the raw proof directly is not recommended and is not covered by
the stable airbender-host public API. This is exposed for rare cases,
for example when a project depends on both airbender-host and direct
Airbender crates at the same time.