pub struct GpuProver { /* private fields */ }Expand description
GPU prover wrapper that owns and reuses a single UnrolledProver instance.
Poisoning
Actual proving happens on a separate thread, and in case the program cannot be proven, the prover can panic. Prover panics are not unwind safe, so the thread and the prover will be disposed of, making this prover object poisoned, e.g. not usable for future proving attempts. Once poisoned, the prover will return an error on all operations.
After poisioning, you can instantiate a new prover if required.
Implementations